.. _swh-loader-mercurial:

Software Heritage - Mercurial loader
====================================

Loader for `Mercurial <https://www.mercurial-scm.org/>`_ repositories.


Reference Documentation
-----------------------

.. toctree::
   :maxdepth: 2

   /apidoc/swh.loader.mercurial
